<?php
/**
 * Aneeq Theme Functions
 */
	
//Aneeq Text Domain
define("aneeq", "aneeq");

//Aneeq Theme URL
define("ANEEQ_THEME_URL", get_template_directory_uri());
define("ANEEQ_THEME_DIR", get_template_directory());

//Aneeq Theme Version
//define("ANEEQ_THEME_VERSION", "1.0.0");

//Aneeq Theme Option Panel CSS and JS Backend
add_action('wp_enqueue_scripts','aneeq_backend_resources');

// On theme activation add defaults theme settings and data
add_action( 'after_setup_theme', 'aneeq_default_theme_options_setup', 'theme_prefix_setup' );

//Include Customizer File
require get_template_directory() . '/include/customizer.php';

function aneeq_default_theme_options_setup() {
	
	// Load text domain for translation-ready
    load_theme_textdomain( 'aneeq', ANEEQ_THEME_DIR . '/languages' );
	add_theme_support( 'title-tag' );
	
    // Logo
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
		'flex-height'  => true,
	));
	
	// Set the content_width with 900
	if ( ! isset( $content_width ) ) $content_width = 900;
	
	$defaults = array(
		'default-image'          => '',
		'width'                  => 0,
		'height'                 => 0,
		'flex-height'            => false,
		'flex-width'             => false,
		'uploads'                => true,
		'random-default'         => false,
		'header-text'            => true,
		'default-text-color'     => '',
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	);
	add_theme_support( 'custom-header', $defaults );

	$defaults = array(
		'default-color'          => '',
		'default-image'          => '',
		'default-repeat'         => 'repeat',
		'default-position-x'     => 'left',
		'default-position-y'     => 'top',
		'default-size'           => 'auto',
		'default-attachment'     => 'scroll',
		'wp-head-callback'       => '_custom_background_cb',
		'admin-head-callback'    => '',
		'admin-preview-callback' => ''
	);
	add_theme_support( 'custom-background', $defaults );
	
	add_editor_style('css/editor-style.css');
}

//modify page / post title using title filter
add_filter('wp_title', 'aneeq_filter_pagetitle');
function aneeq_filter_pagetitle($title) {
    //check if its a blog post
    return $title = $title . ' | ';  bloginfo( 'name' );
}

//Create table for subscribers list
add_action( 'after_switch_theme','aneeq_subscribers_data');
function aneeq_subscribers_data() {
	global $wpdb;
	$aneeq_table_name = $wpdb->prefix . 'aneeq_subscribers';
	$aneeq_charset_collate = $wpdb->get_charset_collate();
	$aneeq_sql = "CREATE TABLE IF NOT EXISTS $aneeq_table_name (
	id int NOT NULL AUTO_INCREMENT,
	f_name VARCHAR(255) NOT NULL,
	l_name VARCHAR(255) NOT NULL,
	email VARCHAR(255) NOT NULL,
	date timestamp,
	extra_detail text,
	UNIQUE KEY id (id)
	) $aneeq_charset_collate;";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $aneeq_sql );
	
	// Aneeq Contact Form
	$aneeq_contact_form_table = $wpdb->prefix . 'aneeq_contact_form';
	$aneeq_create_contact_form_query = "CREATE TABLE IF NOT EXISTS `$aneeq_contact_form_table` (
	`id` int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
	`f_name` varchar(256) NOT NULL,
	`l_name` varchar(256) NOT NULL,
	`email` varchar(256) NOT NULL,
	`subject` varchar(256) NOT NULL,
	`message` text NOT NULL,
	`date_time` datetime NOT NULL,
	`status` varchar(50) NOT NULL
	) $aneeq_charset_collate";
	$wpdb->query($aneeq_create_contact_form_query);
}

//Add Theme Support Like - featured image, image crop, post format, rss feed
add_theme_support('post-thumbnails');			// featured image
add_theme_support( 'automatic-feed-links' );	//	rss feed

/**
 * Aneeq - Load Theme Option Panel CSS and JS Start
 */
function aneeq_backend_resources(){
	// aneeq theme css
	wp_enqueue_style( 'aneeq-style', get_stylesheet_uri());
	wp_enqueue_style( 'aneeq-bootstrap-min-css', get_template_directory_uri() . '/css/bootstrap.min.css');	
	wp_enqueue_style( 'aneeq-bootstrap-css', get_template_directory_uri() . '/css/bootstrap.css');	
	
	// check is any custom color is set and get the custom color for skin
	$aneeq_option_settings = get_option('aneeq_general_settings');
	if(!isset($aneeq_option_settings['aneeq_skin_theme_color'])){
		wp_enqueue_style( 'aneeq-screen-css', get_template_directory_uri() . '/css/style.css', array(), 'screen', 'skins' );	// default skin
	}
	
	//JS & CSS
	wp_enqueue_style( 'aneeq-font-awesome-css', get_template_directory_uri() . '/css/font-awesome.css');
	wp_enqueue_style('style', get_stylesheet_uri());
	add_action('wp_enqueue_scripts', 'example_enqueue_styles');	
	wp_enqueue_script('jquery');
	wp_enqueue_script('aneeq-main-js', get_template_directory_uri() . '/js/main.js', array('jquery'), 1.0, true);
	wp_enqueue_script('aneeq-bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery'));	
	//Slider
	wp_enqueue_script('aneeq-owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.js');
	wp_enqueue_style( 'aneeq-owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
}
//Aneeq - Load Theme Option Panel CSS and JS End


/**
 * Aneeq Widgets Start
 */
function aneeq_theme_widgets() {
	
	// Blog / Page Sidebar Widget
	register_sidebar( array(
		'name' 			=> 'Sidebar Widget',
		'id' 			=> 'sidebar-widget',
		'before_widget' => '<aside class="widget">',
		'after_widget' 	=> '</aside>',
		'before_title' 	=> '<h4 class="widget-title">',
		'after_title' 	=> '</h4>'
	));
	
	// Get Footer Layout Settings
	$aneeq_footer_column_layout = get_theme_mod('aneeq_footer_column_layout', 3);
	if($aneeq_footer_column_layout == 1) $aneeq_footer_class_name = "col-md-12 col-sm-12 col-xs-12";	// one column
	if($aneeq_footer_column_layout == 2) $aneeq_footer_class_name = "col-md-6 col-sm-6 col-xs-12";		// two column
	if($aneeq_footer_column_layout == 3) $aneeq_footer_class_name = "col-md-4 col-sm-6 col-xs-12";		// three column
	if($aneeq_footer_column_layout == 4) $aneeq_footer_class_name = "col-md-3 col-sm-6 col-xs-12";		// four column
	// Footer Widget 1
	register_sidebar( array(
		'name'			=> 'Footer Widget',
		'id'			=> 'aneeq-footer-widget',
		'description'	=> 'This is footer widget area of the theme.',
		'before_widget' => "<aside class='$aneeq_footer_class_name widget'>",
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h4 class="widget-title">',
		'after_title'	=> '</h4>',
	));
}
add_action('widgets_init', 'aneeq_theme_widgets');
// Aneeq Widgets End

//Register area for custom menu
add_action( 'init', 'aneeq_menu' );
function aneeq_menu() {
	register_nav_menu( 'primary-menu', __( 'Primary Menu','aneeq' ) );
	require get_template_directory() . '/include/walker.php';
}
// Include Walker file